Module atomic

Module atomic 

Custom atomic types for XPath.

Where atomic types cannot be defined using standard Rust types or external packages such as chrono, ordered_float and rust_decimal, Xee defines its own types.

Structs

Duration
A Duration is a combination of a YearMonthDuration and [chrono::Duration`].
GDay
A GDay is a combination of a day and an optional chrono::FixedOffset.
GMonth
A GMonth is a combination of a month and an optional chrono::FixedOffset.
GMonthDay
A GMonthDay is a combination of a month and a day, and an optional chrono::FixedOffset.
GYear
A GYear is a combination of a year and an optional chrono::FixedOffset.
GYearMonth
A GYearMonth is a combination of a year and a month, and an optional chrono::FixedOffset.
NaiveDateTimeWithOffset
A NaiveDateTimeWithOffset is a combination of a chrono::NaiveDateTime and an optional chrono::FixedOffset.
NaiveDateWithOffset
A NaiveDateWithOffset is a combination of a chrono::NaiveDate and an optional chrono::FixedOffset.
NaiveTimeWithOffset
A NaiveTimeWithOffset is a combination of a chrono::NaiveTime and an optional chrono::FixedOffset.
YearMonthDuration

Enums

BinaryType
The types of binary supported as atomic values.
StringType
The types of string supported as atomic values.