Itemable

Trait Itemable 

pub trait Itemable {
    // Required method
    fn to_item(&self, documents: &Documents) -> Result<Item>;
}
Something that can be converted into an Item using a [Document]

This can be an item, but also a DocumentHandle

Required Methods

fn to_item(&self, documents: &Documents) -> Result<Item>

Convert this itemable into an Item

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Itemable for Node

Source

fn to_item(&self, _documents: &Documents) -> Result<Item>

Implementors