pub trait Itemable {
// Required method
fn to_item(&self, documents: &Documents) -> Result<Item>;
}Expand description
Something that can be converted into an Item using a [Document]
This can be an item, but also a DocumentHandle
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".